@@ -39,6 +39,7 @@ class LinFrame:
 		self.publisher = None
 		self.length = length
 		orderedSignals = sorted(signals.items(), key=lambda x: x[0])
+		self.signal_map = orderedSignals
 		self.signals = [i[1] for i in orderedSignals]
 		self._pattern = self._frame_pattern(length * 8, orderedSignals)
 		self._packer = bitstruct.compile(self._pattern)
@@ -73,7 +74,7 @@ class LinFrame:
 		"""
 		message = []
 		for signal in self.signals:
-			if data.get(signal.name):
+			if signal.name in data.keys():
 				if signal.is_array():
 					message += data.get(signal.name)
 				else:
@@ -91,7 +92,7 @@ class LinFrame:
 		"""
 		converted = {}
 		for value in data.items():
-			if converters[value[0]] is None:
+			if value[0] not in converters.keys():
 				raise ValueError('No encoder found for ' + value[0])
 			converted[value[0]] = converters[value[0]].encode(value[1], self._get_signal(value[0]))
 		return self.raw(converted)
@@ -122,7 +123,7 @@ class LinFrame:
 		tmp = self.parse_raw(data)
 		output = {}
 		for value in tmp.items():
-			if converters[value[0]] is None:
+			if value[0] not in converters.keys():
 				raise ValueError('No decoder found for ' + value[0])
 			output[value[0]] = converters[value[0]].decode(value[1], self._get_signal(value[0]))
 		return output
