@@ -179,7 +179,7 @@ def _link_ldf_signals(json: dict, ldf: LDF):
 				slave = ldf.slave(subscriber)
 				if slave is None:
 					raise ValueError(f"Signal {signal_obj.name} references non existent node {subscriber}")
-				slave.subscribes_to.append(signal)
+				slave.subscribes_to.append(signal_obj)
 				signal_obj.subscribers.append(slave)
 
 
@@ -240,7 +240,8 @@ class LDFTransformer(Transformer):
 		try:
 			return float(i)
 		except ValueError:
-			return self.parse_int(i)
+			# TODO: dead code
+			return self.parse_integer(i)
 
 	def ldf_identifier(self, tree):
 		return tree[0][0:]
@@ -303,10 +304,10 @@ class LDFTransformer(Transformer):
 		return tree[0]
 
 	def signal_default_value_single(self, tree):
-		return int(tree[0])
+		return tree[0]
 
 	def signal_default_value_array(self, tree):
-		return tree[0]
+		return tree[0:]
 
 	def diagnostic_signals(self, tree):
 		return ("diagnostic_signals", [])
